@@ -1,17 +1,17 @@
 package Module::Install::Bundle;
 
 use strict;
-use Module::Install::Base;
-use Cwd ();
-use File::Find ();
-use File::Copy ();
-use File::Basename ();
+use Cwd                   ();
+use File::Find            ();
+use File::Copy            ();
+use File::Basename        ();
+use Module::Install::Base ();
 
-use vars qw{$VERSION $ISCORE @ISA};
+use vars qw{$VERSION @ISA $ISCORE};
 BEGIN {
-	$VERSION = '0.89';
+	$VERSION = '0.90';
+	@ISA     = 'Module::Install::Base';
 	$ISCORE  = 1;
-	@ISA     = qw{Module::Install::Base};
 }
 
 sub auto_bundle {
