@@ -3,11 +3,11 @@ package Module::Install::External;
 # Provides dependency declarations for external non-Perl things
 
 use strict;
-use Module::Install::Base;
+use Module::Install::Base ();
 
 use vars qw{$VERSION $ISCORE @ISA};
 BEGIN {
-	$VERSION = '0.89';
+	$VERSION = '0.90';
 	$ISCORE  = 1;
 	@ISA     = qw{Module::Install::Base};
 }
